@@ -44,6 +44,9 @@ INTERNALERROR_CALLNOTIFICATIONERROR = 'InternalError.CallNotificationError'
 # STS 接口调用失败。
 INTERNALERROR_CALLSTSERROR = 'InternalError.CallStsError'
 
+# TAT 接口调用失败。
+INTERNALERROR_CALLTATERROR = 'InternalError.CallTATError'
+
 # Tag 接口调用失败。
 INTERNALERROR_CALLTAGERROR = 'InternalError.CallTagError'
 
@@ -167,6 +170,9 @@ INVALIDPARAMETERVALUE_INVALIDCLBREGION = 'InvalidParameterValue.InvalidClbRegion
 # 过滤条件无效。
 INVALIDPARAMETERVALUE_INVALIDFILTER = 'InvalidParameterValue.InvalidFilter'
 
+# 高性能计算集群ID无效。
+INVALIDPARAMETERVALUE_INVALIDHPCCLUSTERID = 'InvalidParameterValue.InvalidHpcClusterId'
+
 # 镜像ID无效。
 INVALIDPARAMETERVALUE_INVALIDIMAGEID = 'InvalidParameterValue.InvalidImageId'
 
@@ -194,6 +200,9 @@ INVALIDPARAMETERVALUE_INVALIDSCHEDULEDACTIONID = 'InvalidParameterValue.InvalidS
 # 定时任务名称包含无效字符。
 INVALIDPARAMETERVALUE_INVALIDSCHEDULEDACTIONNAMEINCLUDEILLEGALCHAR = 'InvalidParameterValue.InvalidScheduledActionNameIncludeIllegalChar'
 
+# 安全组ID无效。
+INVALIDPARAMETERVALUE_INVALIDSECURITYGROUPID = 'InvalidParameterValue.InvalidSecurityGroupId'
+
 # 快照ID无效。
 INVALIDPARAMETERVALUE_INVALIDSNAPSHOTID = 'InvalidParameterValue.InvalidSnapshotId'
 
@@ -347,6 +356,9 @@ RESOURCENOTFOUND_AUTOSCALINGNOTIFICATIONNOTFOUND = 'ResourceNotFound.AutoScaling
 # 指定的 CMQ queue 不存在。
 RESOURCENOTFOUND_CMQQUEUENOTFOUND = 'ResourceNotFound.CmqQueueNotFound'
 
+# 命令不存在。
+RESOURCENOTFOUND_COMMANDNOTFOUND = 'ResourceNotFound.CommandNotFound'
+
 # 指定的实例不存在。
 RESOURCENOTFOUND_INSTANCESNOTFOUND = 'ResourceNotFound.InstancesNotFound'
 
